@@ -3,14 +3,14 @@
    # echo output to screen
    cat("\n")
    cat("*************************** tdm ***********************************\n")
-   cat("                Therapeutic Drug Monitoring                        \n\n")
-   cat("                          v 2.2.1                                  \n\n")   
+   cat("           An R Tool for Therapeutic Drug Monitoring               \n\n")
+   cat("                          v 2.2.2                                  \n\n")   
    cat("  TDM is created for your own personal uses and testing purposes.  \n")
    cat("  TDM shall be used as a guide or a decision support tool only.    \n")  
    cat("  Medical decisions should NOT be solely based on the results of   \n")
    cat("  this program. Although this program has been tested thoroughly,  \n")
    cat("  the accuracy of the information cannot be guaranteed. Once you   \n")
-   cat("  use TDM, you have automatically agreed with this disclaimer.     \n\n")   
+   cat("  use tdm, you have automatically agreed with this disclaimer.     \n\n")   
    cat("             Please type 'run()' to get started.                   \n")
    cat("*******************************************************************\n\n")
 
